==> wedge-0.6.0.jar: io/dominic/wedge/user.clj <==
(ns io.dominic.wedge.user
  (:require
    [clojure.edn :as edn]
    [clojure.java.classpath :refer [classpath-directories]]
    [clojure.java.io :as io]
    [clojure.java.shell :as sh]
    [clojure.set :as set]
    [clojure.string :as string]
    [clojure.tools.namespace.repl :as namespace.repl]
    [io.dominic.wedge.dev :as wedge.dev]))

(when (try
        (Class/forName "org.slf4j.bridge.SLF4JBridgeHandler")
        (catch ClassNotFoundException _
          false))
  (eval
    `(do
       (org.slf4j.bridge.SLF4JBridgeHandler/removeHandlersForRootLogger)
       (org.slf4j.bridge.SLF4JBridgeHandler/install))))

(def ^:private basis (some-> (System/getProperty "clojure.basis")
                             io/reader
                             (java.io.PushbackReader.)
                             edn/read))

(doto (Thread.
        (fn []
          (try
            (when (.exists (io/file ".clj-kondo"))
              (sh/sh "clj-kondo" "--no-warnings" "--parallel" "--lint"
                     (string/join java.io.File/pathSeparator (:classpath-roots basis))))
            (catch Throwable _
              ;; Silent error is absolutely fine here.  This is simply a
              ;; convenience for users.
              ,))))
  (.setDaemon true)
  (.setName "wedge-clj-kondo-cacher")
  (.start))

(let [build-paths (when basis
                    (map (fn [path]
                           (.getCanonicalFile (io/file path)))
                         (mapcat
                           (fn [path]
                             (if (keyword? path)
                               (let [paths (get-in basis [:aliases path])]
                                 (when (sequential? paths)
                                   paths))
                               [path]))
                           (mapcat
                             (fn [[k v]]
                               (when (.contains (str k) ":build")
                                 (cond
                                   (map? v)
                                   (concat (:extra-paths v) (:replace-paths v))
                                   (sequential? v)
                                   v)))
                             (:aliases basis)))))]
  (apply namespace.repl/set-refresh-dirs
         (set/difference
           (set (map #(.getCanonicalFile %) (classpath-directories)))
           (set build-paths))))

(let [lock (Object.)]
  (defn dev
    "Call this to switch to the dev namespace."
    []
    (println "[Wedge] Loading dev")
    (locking lock
      (require 'dev))
    (when-not wedge.dev/system
      (println "[Wedge] Enter (go) to start the system"))
    (in-ns 'dev)))

(defn fixed!
  "If, for some reason, the Clojure code in the project fails to
  compile - we still bring up a REPL to help debug the problem. Once
  the problem has been resolved you can call this function to continue
  development."
  []
  (namespace.repl/refresh-all)
  (in-ns 'dev))

(def refresh namespace.repl/refresh)
(def refresh-all namespace.repl/refresh-all)

==> wedge-0.7.0.jar: io/dominic/wedge/user.clj <==
(ns io.dominic.wedge.user
  "Functions commonly used from a `user` namespace.  Recommended usage is like:
  ```
  (ns user
    (:require [io.dominic.wedge.user :refer :all]))
  ```"
  (:require
    [clojure.edn :as edn]
    [clojure.java.classpath :refer [classpath-directories]]
    [clojure.java.io :as io]
    [clojure.java.shell :as sh]
    [clojure.set :as set]
    [clojure.string :as string]
    [clojure.tools.namespace.repl :as namespace.repl]
    [io.dominic.wedge.dev :as wedge.dev]))

(when (try
        (Class/forName "org.slf4j.bridge.SLF4JBridgeHandler")
        (catch ClassNotFoundException _
          false))
  (eval
    `(do
       (org.slf4j.bridge.SLF4JBridgeHandler/removeHandlersForRootLogger)
       (org.slf4j.bridge.SLF4JBridgeHandler/install))))

(def ^:private basis (some-> (System/getProperty "clojure.basis")
                             io/reader
                             (java.io.PushbackReader.)
                             edn/read))

(doto (Thread.
        (fn []
          (try
            (when (.exists (io/file ".clj-kondo"))
              (sh/sh "clj-kondo" "--no-warnings" "--parallel" "--lint"
                     (string/join java.io.File/pathSeparator (:classpath-roots basis))))
            (catch Throwable _
              ;; Silent error is absolutely fine here.  This is simply a
              ;; convenience for users.
              ,))))
  (.setDaemon true)
  (.setName "wedge-clj-kondo-cacher")
  (.start))

(let [build-paths (when basis
                    (map (fn [path]
                           (.getCanonicalFile (io/file path)))
                         (mapcat
                           (fn [path]
                             (if (keyword? path)
                               (let [paths (get-in basis [:aliases path])]
                                 (when (sequential? paths)
                                   paths))
                               [path]))
                           (mapcat
                             (fn [[k v]]
                               (when (.contains (str k) ":build")
                                 (cond
                                   (map? v)
                                   (concat (:extra-paths v) (:replace-paths v))
                                   (sequential? v)
                                   v)))
                             (:aliases basis)))))]
  (apply namespace.repl/set-refresh-dirs
         (set/difference
           (set (map #(.getCanonicalFile %) (classpath-directories)))
           (set build-paths)
           ;; Remove wedge to aid in using it via :local/root.  This is
           ;; absolutely a hack, there's plenty of other libraries which are
           ;; not reload-safe.  This is entirely here to benefit the
           ;; maintainers of Wedge.
           (set (map
                  #(.getCanonicalFile (io/file %))
                  (get-in basis [:libs 'io.dominic/wedge :paths]))))))

(let [lock (Object.)]
  (defn dev
    "Call this to switch to the dev namespace."
    []
    (println "[Wedge] Loading dev")
    (locking lock
      (require 'dev))
    (when-not wedge.dev/system
      (println "[Wedge] Enter (go) to start the system"))
    (in-ns 'dev)))

(defn fixed!
  "If, for some reason, the Clojure code in the project fails to
  compile - we still bring up a REPL to help debug the problem. Once
  the problem has been resolved you can call this function to continue
  development."
  []
  (namespace.repl/refresh-all)
  (in-ns 'dev))

(def refresh namespace.repl/refresh)
(def refresh-all namespace.repl/refresh-all)
